/* 
 * SDLInvasion a Space Invader clone.
 * Copyright (C) 2002 Laurent GOMEZ & MiKael NAVARRO
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */


#ifndef __PLAYER_H
#define __PLAYER_H

#include "SDL.h"


/* 
 * Data type.
 */
typedef struct View_Player {
   SDL_Surface *sprite, *explosion; /* sprites */
   int x,y; /* position */
   int xvel; /* velocity */
} View_Player;

typedef struct Player {
   int alive; /* is alive ? */
   View_Player *view;
} Player;


/* 
 * Create a new player.
 */
Player *Player_new(SDL_Surface *screen, char *player_sprite);

/* 
 * Destroy a player.
 */
int Player_destroy(Player *player);


/*
 * Player is alive ? return nb of life.
 */
int Player_isAlive(Player *player);

/*
 * Player velocity.
 */
int Player_xvel(Player *player);


/* 
 * Move the player on the left.
 */
int Player_moveLeft(Player *player);

/* 
 * Move the player on the right.
 */
int Player_moveRight(Player *player);

/* 
 * Stop the player.
 */
int Player_stop(Player *player);


/* 
 * Display the player on screen.
 */
int Player_draw(Player *player, SDL_Surface *screen);


/*
 * The Player Shoot.
 */
/*Shoot *Player_shoot(Player *player);*/


/*
 * Detect collision with an Alien.
 */
/*int Player_collide(Player *player, Alien *alien);*/



#endif /* __PLAYER_H */
